==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Input/sid/translations/sid_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="59"/>
        <source>SID Plugin</source>
        <translation>Plugin SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="61"/>
        <source>SID Files</source>
        <translation>File SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="115"/>
        <source>About SID Audio Plugin</source>
        <translation>Tentang Plugin Audio SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="116"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Plugin Audio SID Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="117"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Plugin ini memutar file-file musik Commodore 64 menggunakan pustaka libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="118"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ditulis oleh: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Setelan Plugin SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Resampling cepat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Sample rate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>File database HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Metode resampling:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Panjang lagu baku, det:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>Aktifkan database panjang lagu HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulasi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/Input/sid/translations/sid_plugin_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="id">
<context>
    <name>DecoderSIDFactory</name>
    <message>
        <location filename="../decodersidfactory.cpp" line="59"/>
        <source>SID Plugin</source>
        <translation>Plugin SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="61"/>
        <source>SID Files</source>
        <translation>File SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="115"/>
        <source>About SID Audio Plugin</source>
        <translation>Tentang Plugin Audio SID</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="116"/>
        <source>Qmmp SID Audio Plugin</source>
        <translation>Plugin Audio SID Qmmp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="117"/>
        <source>This plugin plays Commodore 64 music files using libsidplayfp library</source>
        <translation>Plugin ini memutar file-file musik Commodore 64 menggunakan pustaka libsidplayfp</translation>
    </message>
    <message>
        <location filename="../decodersidfactory.cpp" line="118"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>SID Plugin Settings</source>
        <translation>Setelan Plugin SID</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Fast resampling</source>
        <translation>Resampling cepat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="62"/>
        <source>Sample rate:</source>
        <translation>Sample rate:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="69"/>
        <source>HVSC database file:</source>
        <translation>File database HVSC:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Resampling method:</source>
        <translation>Metode resampling:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="93"/>
        <source>Defaults song length, sec:</source>
        <translation>Panjang lagu baku, det:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="100"/>
        <source>Enable HVSC song length database</source>
        <translation>Aktifkan database panjang lagu HVSC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="107"/>
        <source>Emulation:</source>
        <translation>Emulasi:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
</context>
</TS>
